@@ -290,19 +290,19 @@ def configure_logger(simple_name, log_dest=None,
 
     Parameters:
 
-      simple_name (:term:`string`):
+      simple_name (str):
         Simple name (ex. `'api'`) of the single pywbem logger this method
         should affect, or `'all'` to affect all pywbem loggers.
 
         Must be one of the strings in
         :data:`~pywbem._logging.LOGGER_SIMPLE_NAMES`.
 
-      log_dest (:term:`string`):
+      log_dest (str):
         Log destination for the affected pywbem loggers, controlling the
         configuration of its Python logging parameters (log handler,
         message format, and log level).
 
-        If it is a :term:`string`, it must be one of the strings in
+        If it is a :class:`py:str`, it must be one of the strings in
         :data:`~pywbem._logging.LOG_DESTINATIONS` and the Python logging
         parameters of the loggers will be configured accordingly for their
         log handler, message format, and with a logging level of
@@ -313,21 +313,21 @@ def configure_logger(simple_name, log_dest=None,
         If `None`, the Python logging parameters of the loggers will not be
         changed.
 
-      detail_level (:term:`string` or :class:`int` or `None`):
+      detail_level (:class:`py:str` or :class:`py:int` or `None`):
         Detail level for the data in each log record that is generated by
         the affected pywbem loggers.
 
-        If it is a :term:`string`, it must be one of the strings in
+        If it is a :class:`py:str`, it must be one of the strings in
         :data:`~pywbem._logging.LOG_DETAIL_LEVELS` and the loggers will
         be configured for the corresponding detail level.
 
-        If it is an :class:`int`, it defines the maximum size of the log
+        If it is an :class:`py:int`, it defines the maximum size of the log
         records created and the loggers will be configured to output all
         available information up to that size.
 
         If `None`, the detail level configuration will not be changed.
 
-      log_filename (:term:`string`):
+      log_filename (str):
         Path name of the log file (required if the log destination is
         `'file'`; otherwise ignored).
 
@@ -351,7 +351,7 @@ def configure_logger(simple_name, log_dest=None,
 
         If `None`, no WBEM connection will be activated for logging.
 
-      propagate (:class:`py:bool`): Flag controlling whether the
+      propagate (bool): Flag controlling whether the
         affected pywbem logger should propagate log events to its
         parent loggers.
 
@@ -390,7 +390,7 @@ def configure_loggers_from_string(log_configuration_str,
 
     Parameters:
 
-      log_configuration_str (:term:`string`): The log configuration string, in
+      log_configuration_str (str): The log configuration string, in
         the following format::
 
             log_specs := log_spec [ ',' log_spec ]
@@ -407,7 +407,7 @@ def configure_loggers_from_string(log_configuration_str,
           :data:`~pywbem._logging.LOG_DETAIL_LEVELS` list. Default is
           :data:`~pywbem._logging.DEFAULT_LOG_DETAIL_LEVEL`.
 
-      log_filename (:term:`string`):
+      log_filename (str):
         Path name of the log file (required if any log destination is
         `'file'`; otherwise ignored).
 
@@ -430,7 +430,7 @@ def configure_loggers_from_string(log_configuration_str,
 
         If `None`, no WBEM connection will be activated for logging.
 
-      propagate (:class:`py:bool`): Flag controlling whether the
+      propagate (bool): Flag controlling whether the
         affected pywbem logger should propagate log events to its
         parent loggers.
 
