@@ -1,28 +1,46 @@
+# Copyright (C) 2020 Andreas Maier
 """
 This module provides class NocaseList.
 """
 
-from __future__ import print_function, absolute_import
-
 import sys
 import os
+from typing import Callable, AnyStr, Optional, Union
+try:
+    from typing import SupportsIndex  # type: ignore
+except ImportError:
+    from typing_extensions import SupportsIndex  # Python <=3.7
+try:
+    from typing import TypeAlias  # type: ignore
+except ImportError:
+    from typing_extensions import TypeAlias  # Python <=3.9
+if sys.version_info[0:2] >= (3, 9):
+    from collections.abc import Iterable  # type: ignore
+else:
+    # Before py39, collections.abc.Iterable did not support generic type
+    from typing import Iterable
 
 __all__ = ['NocaseList']
 
-if sys.version_info[0] == 2:
-    # pylint: disable=undefined-variable
-    _INTEGER_TYPES = (long, int)  # noqa: F821
-else:
-    _INTEGER_TYPES = (int,)
-
 # This env var is set when building the docs. It causes the methods
 # that are supposed to exist only in a particular Python version, not to be
 # removed, so they appear in the docs.
 BUILDING_DOCS = os.environ.get('BUILDING_DOCS', False)
 
+# Type for values in NocaseList
+Value: TypeAlias = Optional[AnyStr]
+
+# Type for returning single values or slices
+ValueOrNocaseList: TypeAlias = Union[Value, 'NocaseList']
+
+# Type for other argument in rich comparison methods
+OtherList: TypeAlias = Iterable[Value]  # pylint: disable=unsubscriptable-object
+
+# Type for index argument that can also specify a slice
+IndexOrSlice: TypeAlias = Union[SupportsIndex, slice]
+
 
 class NocaseList(list):
-    # pylint: disable=line-too-long
     """
     A case-insensitive and case-preserving list.
 
@@ -45,8 +63,7 @@ class NocaseList(list):
 
     The list supports serialization via the Python :mod:`py:pickle` module.
     To save space and time, only the originally cased list is serialized.
-    """  # noqa E401
-    # pylint: enable=line-too-long
+    """
 
     # Methods not implemented:
     #
@@ -56,6 +73,9 @@ class NocaseList(list):
     # * __sizeof__(self): The method inherited from list is used; no reason
     #   to have a different implementation.
     #
+    # * __len__(self): The method inherited from list is used; no reason
+    #   to have a different implementation.
+    #
     # __repr__(): The method inherited from list is used; no reason
     #   to have a different implementation.
     #
@@ -65,7 +85,7 @@ class NocaseList(list):
     # __iter__(): The method inherited from list is used; no reason
     #   to have a different implementation.
 
-    def __init__(self, iterable=()):
+    def __init__(self, iterable=()) -> None:
         """
         Initialize the list with the items in the specified iterable.
         """
@@ -79,15 +99,13 @@ class NocaseList(list):
         # many cases, casefolding the input list is more expensive than
         # copying it (plus the overhead to check that).
         if isinstance(iterable, NocaseList):
-            try:
-                # pylint: disable=protected-access
-                self._casefolded_list = iterable._casefolded_list.copy()
-            except AttributeError:  # No copy() on Python 2
-                self._casefolded_list = self._new_casefolded_list(self)
+            # pylint: disable=protected-access
+            casefolded_list = iterable._casefolded_list.copy()
         else:
-            self._casefolded_list = self._new_casefolded_list(self)
+            casefolded_list = self._new_casefolded_list(self)
+        self._casefolded_list: list = casefolded_list
 
-    def _new_casefolded_list(self, lst):
+    def _new_casefolded_list(self, lst: OtherList) -> list:
         """
         Return a casefolded list from the input list.
         """
@@ -96,44 +114,46 @@ class NocaseList(list):
             result.append(self._casefolded_value(value))
         return result
 
-    def _casefolded_value(self, value):
+    def _casefolded_value(self, value: Value) -> Value:
         """
         This method returns the casefolded value and handles the case of value
-        being `None`.
+        being `None`. The value may be a string or an list/tuple of strings.
         """
         if value is None:
             return None
+        if isinstance(value, (list, tuple)):
+            return [self._casefolded_value(v) for v in value]
         return self.__casefold__(value)
 
     @staticmethod
-    def __casefold__(value):
+    def __casefold__(value: AnyStr) -> AnyStr:
         """
         This method implements the case-insensitive behavior of the class.
 
         It returns a case-insensitive form of the input value by calling a
         "casefold method" on the value. The input value will not be `None`.
 
-        The casefold method called by this method is :meth:`py2:str.lower` on
-        Python 2, and on Python 3 it is :meth:`py:str.casefold`, falling back
-        to :meth:`py:bytes.lower` if it does not exist.
+        The casefold method called by this method is :meth:`py:str.casefold`.
+        If that method does not exist on the key value (e.g. because it is a
+        byte string), :meth:`py:bytes.lower` is called, for compatibility with
+        earlier versions of the package.
 
         This method can be overridden by users in order to change the
         case-insensitive behavior of the class.
         See :ref:`Overriding the default casefold method` for details.
 
         Parameters:
-          value (str or unicode or bytes): Input value. Will not be `None`.
+          value (str or bytes): Input value. Will not be `None`.
 
         Returns:
-          str or unicode or bytes: Case-insensitive form of the input value.
+          str or bytes: Case-insensitive form of the input value.
 
         Raises:
           AttributeError: The value does not have the casefold method.
         """
         try:
-            return value.casefold()
+            return value.casefold()  # type: ignore
         except AttributeError:
-            # Either Python 2, or Python 3 and a byte string key
             return value.lower()
 
     def __getstate__(self):
@@ -143,9 +163,6 @@ class NocaseList(list):
         In order to save space and time, only the list with the originally
         cased items is saved, but not the second list with the casefolded
         items.
-
-        On Python 2, the 'pickle' module does not call :meth:`__setstate__`,
-        so this optimzation has only be implemented for Python 3.
         """
         # This copies the state of the inherited list even though it is
         # not visible in self.__dict__.
@@ -156,35 +173,32 @@ class NocaseList(list):
     def __setstate__(self, state):
         """
         Called when unpickling the object, see :meth:`py:object.__setstate__`.
-
-        On Python 2, the 'pickle' module does not call this method, so this
-        optimzation has only be implemented for Python 3.
         """
         self.__dict__.update(state)
         self._casefolded_list = self._new_casefolded_list(self)
 
-    def __setitem__(self, index, value):
+    def __setitem__(self, index: IndexOrSlice, value: Value) -> None:
         """
-        Update the value of the item at an existing index in the list.
+        Update the value of the item at an existing index or slice in the list.
 
         Invoked using ``ncl[index] = value``.
 
         Raises:
           AttributeError: The value does not have the casefold method.
         """
-        super(NocaseList, self).__setitem__(index, value)
-        self._casefolded_list[index] = self._casefolded_value(value)
+        super(NocaseList, self).__setitem__(index, value)  # type: ignore
+        self._casefolded_list[index] = self._casefolded_value(value)  # type: ignore # noqa: E501 pylint: disable=line-too-long
 
-    def __delitem__(self, index):
+    def __delitem__(self, index: IndexOrSlice) -> None:
         """
-        Delete an item at an existing index from the list.
+        Delete an item at an existing index or slice from the list.
 
         Invoked using ``del ncl[index]``.
         """
         super(NocaseList, self).__delitem__(index)
         del self._casefolded_list[index]
 
-    def __contains__(self, value):
+    def __contains__(self, value: Value) -> bool:
         """
         Return a boolean indicating whether the list contains at least one
         item with the value, by looking it up case-insensitively.
@@ -196,7 +210,7 @@ class NocaseList(list):
         """
         return self._casefolded_value(value) in self._casefolded_list
 
-    def __add__(self, other):
+    def __add__(self, other: OtherList) -> 'NocaseList':
         """
         Return a new :class:`NocaseList` object that contains the items from
         the left hand operand (``self``) and the items from the right hand
@@ -219,7 +233,7 @@ class NocaseList(list):
         lst.extend(other)
         return lst
 
-    def __iadd__(self, other):
+    def __iadd__(self, other: OtherList) -> 'NocaseList':
         """
         Extend the left hand operand (``self``) by the items from the right
         hand operand (``other``).
@@ -235,7 +249,7 @@ class NocaseList(list):
         self.extend(other)
         return self
 
-    def __mul__(self, number):
+    def __mul__(self, number: int) -> 'NocaseList':  # type: ignore
         """
         Return a new :class:`NocaseList` object that contains the items from
         the left hand operand (``self``) as many times as specified by the right
@@ -247,7 +261,9 @@ class NocaseList(list):
 
         Invoked using ``ncl * number``.
         """
-        if not isinstance(number, _INTEGER_TYPES):
+        # Despite using type hints, passing a non-int object does not raise
+        # any exception, so we still need to check the type:
+        if not isinstance(number, int):
             raise TypeError(
                 "Cannot multiply NocaseList by non-integer of type {t}".
                 format(t=type(number)))
@@ -256,7 +272,7 @@ class NocaseList(list):
             lst.extend(self)
         return lst
 
-    def __rmul__(self, number):
+    def __rmul__(self, number: int) -> 'NocaseList':  # type: ignore
         """
         Return a new :class:`NocaseList` object that contains the items from
         the right hand operand (``self``) as many times as specified by the left
@@ -271,7 +287,7 @@ class NocaseList(list):
         lst = self * number  # Delegates to __mul__()
         return lst
 
-    def __imul__(self, number):
+    def __imul__(self, number: int) -> 'NocaseList':  # type: ignore
         """
         Change the left hand operand (``self``) so that it contains the items
         from the original left hand operand (``self``) as many times as
@@ -281,9 +297,9 @@ class NocaseList(list):
 
         Invoked using ``ncl *= number``.
         """
-        # Note: It is unusual that the method has to return self, but it was
-        # verified that this is necessary.
-        if not isinstance(number, _INTEGER_TYPES):
+        # Despite using type hints, passing a non-int object does not raise
+        # any exception, so we still need to check the type:
+        if not isinstance(number, int):
             raise TypeError(
                 "Cannot multiply NocaseList by non-integer of type {t}".
                 format(t=type(number)))
@@ -294,9 +310,11 @@ class NocaseList(list):
             self_items = list(self)
             for _ in range(0, number - 1):
                 self.extend(self_items)
+        # Note: It is unusual that the method has to return self, but it was
+        # verified that this is necessary.
         return self
 
-    def __reversed__(self):
+    def __reversed__(self) -> 'NocaseList':  # type: ignore
         """
         Return a shallow copy of the list that has its items reversed in order.
 
@@ -306,7 +324,7 @@ class NocaseList(list):
         lst.reverse()
         return lst
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         """
         Return a boolean indicating whether the list and the other list are
         equal, by comparing corresponding list items case-insensitively.
@@ -321,12 +339,15 @@ class NocaseList(list):
             method.
         """
         if isinstance(other, NocaseList):
-            other = other._casefolded_list  # pylint: disable=protected-access
-        else:
-            other = self._new_casefolded_list(other)
-        return self._casefolded_list == other
+            # pylint: disable=protected-access
+            return self._casefolded_list == other._casefolded_list
 
-    def __ne__(self, other):
+        if isinstance(other, Iterable):
+            return self._casefolded_list == self._new_casefolded_list(other)
+
+        return NotImplemented
+
+    def __ne__(self, other: object) -> bool:
         """
         Return a boolean indicating whether the list and the other list are
         not equal, by comparing corresponding list items case-insensitively.
@@ -340,13 +361,12 @@ class NocaseList(list):
           AttributeError: A value in the other list does not have the casefold
             method.
         """
-        if isinstance(other, NocaseList):
-            other = other._casefolded_list  # pylint: disable=protected-access
-        else:
-            other = self._new_casefolded_list(other)
-        return self._casefolded_list != other
+        eq = self.__eq__(other)
+        if eq is NotImplemented:
+            return NotImplemented
+        return not eq
 
-    def __gt__(self, other):
+    def __gt__(self, other: object) -> bool:
         """
         Return a boolean indicating whether the list is greater than the other
         list, by comparing corresponding list items case-insensitively.
@@ -361,12 +381,15 @@ class NocaseList(list):
             method.
         """
         if isinstance(other, NocaseList):
-            other = other._casefolded_list  # pylint: disable=protected-access
-        else:
-            other = self._new_casefolded_list(other)
-        return self._casefolded_list > other
+            # pylint: disable=protected-access
+            return self._casefolded_list > other._casefolded_list
 
-    def __lt__(self, other):
+        if isinstance(other, Iterable):
+            return self._casefolded_list > self._new_casefolded_list(other)
+
+        return NotImplemented
+
+    def __lt__(self, other: object) -> bool:
         """
         Return a boolean indicating whether the list is less than the other
         list, by comparing corresponding list items case-insensitively.
@@ -381,12 +404,15 @@ class NocaseList(list):
             method.
         """
         if isinstance(other, NocaseList):
-            other = other._casefolded_list  # pylint: disable=protected-access
-        else:
-            other = self._new_casefolded_list(other)
-        return self._casefolded_list < other
+            # pylint: disable=protected-access
+            return self._casefolded_list < other._casefolded_list
 
-    def __ge__(self, other):
+        if isinstance(other, Iterable):
+            return self._casefolded_list < self._new_casefolded_list(other)
+
+        return NotImplemented
+
+    def __ge__(self, other: object) -> bool:
         """
         Return a boolean indicating whether the list is greater than or
         equal to the other list, by comparing corresponding list items
@@ -401,13 +427,12 @@ class NocaseList(list):
           AttributeError: A value in the other list does not have the casefold
             method.
         """
-        if isinstance(other, NocaseList):
-            other = other._casefolded_list  # pylint: disable=protected-access
-        else:
-            other = self._new_casefolded_list(other)
-        return self._casefolded_list >= other
+        lt = self.__lt__(other)
+        if lt is NotImplemented:
+            return NotImplemented
+        return not lt
 
-    def __le__(self, other):
+    def __le__(self, other: object) -> bool:
         """
         Return a boolean indicating whether the list is less than or
         equal to the other list, by comparing corresponding list items
@@ -422,13 +447,12 @@ class NocaseList(list):
           AttributeError: A value in the other list does not have the casefold
             method.
         """
-        if isinstance(other, NocaseList):
-            other = other._casefolded_list  # pylint: disable=protected-access
-        else:
-            other = self._new_casefolded_list(other)
-        return self._casefolded_list <= other
+        gt = self.__gt__(other)
+        if gt is NotImplemented:
+            return NotImplemented
+        return not gt
 
-    def count(self, value):
+    def count(self, value: Value) -> int:
         """
         Return the number of times the specified value occurs in the list,
         comparing the value and the list items case-insensitively.
@@ -438,30 +462,21 @@ class NocaseList(list):
         """
         return self._casefolded_list.count(self._casefolded_value(value))
 
-    def copy(self):
+    def copy(self) -> 'NocaseList':
         """
         Return a shallow copy of the list.
-
-        Note: This method is supported on Python 2 and Python 3, even though
-        the built-in list class only supports it on Python 3.
         """
         return NocaseList(self)
 
-    def clear(self):
+    def clear(self) -> None:
         """
         Remove all items from the list (and return None).
-
-        Note: This method is supported on Python 2 and Python 3, even though
-        the built-in list class only supports it on Python 3.
         """
-        try:
-            super(NocaseList, self).clear()
-            self._casefolded_list.clear()
-        except AttributeError:
-            del self[:]
-            del self._casefolded_list[:]
+        super(NocaseList, self).clear()
+        self._casefolded_list.clear()
 
-    def index(self, value, start=0, stop=9223372036854775807):
+    def index(self, value: Value, start: SupportsIndex = 0,
+              stop: SupportsIndex = 9223372036854775807) -> int:
         """
         Return the index of the first item that is equal to the specified
         value, comparing the value and the list items case-insensitively.
@@ -477,7 +492,7 @@ class NocaseList(list):
         return self._casefolded_list.index(
             self._casefolded_value(value), start, stop)
 
-    def append(self, value):
+    def append(self, value: Value) -> None:
         """
         Append the specified value as a new item to the end of the list
         (and return None).
@@ -488,7 +503,7 @@ class NocaseList(list):
         super(NocaseList, self).append(value)
         self._casefolded_list.append(self._casefolded_value(value))
 
-    def extend(self, iterable):
+    def extend(self, values: Iterable) -> None:
         """
         Extend the list by the items in the specified iterable
         (and return None).
@@ -497,17 +512,17 @@ class NocaseList(list):
           AttributeError: A value in the iterable does not have the casefold
             method.
         """
-        super(NocaseList, self).extend(iterable)
+        super(NocaseList, self).extend(values)
         # The following is a circumvention for a behavior of the 'pickle' module
         # that during unpickling may call this method on an object that has
         # been created with __new__() without calling __init__().
         try:
-            for value in iterable:
+            for value in values:
                 self._casefolded_list.append(self._casefolded_value(value))
         except AttributeError:
             self._casefolded_list = self._new_casefolded_list(self)
 
-    def insert(self, index, value):
+    def insert(self, index: SupportsIndex, value: Value) -> None:
         """
         Insert a new item with specified value before the item at the specified
         index (and return None).
@@ -518,7 +533,7 @@ class NocaseList(list):
         super(NocaseList, self).insert(index, value)
         self._casefolded_list.insert(index, self._casefolded_value(value))
 
-    def pop(self, index=-1):
+    def pop(self, index: SupportsIndex = -1) -> Value:
         """
         Return the value of the item at the specified index and also remove it
         from the list.
@@ -526,7 +541,7 @@ class NocaseList(list):
         self._casefolded_list.pop(index)
         return super(NocaseList, self).pop(index)
 
-    def remove(self, value):
+    def remove(self, value: Value) -> None:
         """
         Remove the first item from the list whose value is equal to the
         specified value (and return None), comparing the value and the list
@@ -538,14 +553,15 @@ class NocaseList(list):
         self._casefolded_list.remove(self._casefolded_value(value))
         super(NocaseList, self).remove(value)
 
-    def reverse(self):
+    def reverse(self) -> None:
         """
         Reverse the items in the list in place (and return None).
         """
         super(NocaseList, self).reverse()
         self._casefolded_list = self._new_casefolded_list(self)
 
-    def sort(self, key=None, reverse=False):
+    def sort(self, *, key: Optional[Callable] = None,
+             reverse: bool = False) -> None:
         """
         Sort the items in the list in place (and return None).
 
@@ -571,11 +587,3 @@ class NocaseList(list):
 
         super(NocaseList, self).sort(key=casefolded_key, reverse=reverse)
         self._casefolded_list = self._new_casefolded_list(self)
-
-
-# Remove methods that should only be present in a particular Python version.
-# If the documentation is being built, the methods are not removed in order to
-# show them in the documentation.
-if sys.version_info[0] == 2 and not BUILDING_DOCS:
-    del NocaseList.__setstate__
-    del NocaseList.__getstate__
