@@ -14,19 +14,32 @@
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
 
-# There are submodules, but clients shouldn't need to know about them.
-# Importing just this module is enough.
-# These are explicitly safe for 'import *'
+"""
+Definition of the package version, and check for supported Python versions.
+"""
 
-"""
-Version of the pywbem package.
-"""
+try:
+    from ._version_scm import version, version_tuple
+except ImportError:
+    version = "unknown"
+    version_tuple = ("unknown")
+
+__all__ = ['__version__', '__version_tuple__']
 
 #: The full version of this package including any development levels, as a
-#: :term:`string`.
+#: string.
 #:
 #: Possible formats for this version string are:
 #:
-#: * "M.N.P.devD": Development level D of a not yet released version M.N.P
+#: * "M.N.Pa1.dev7+g1234567": A not yet released version M.N.P
 #: * "M.N.P": A released version M.N.P
-__version__ = '1.7.3'
+__version__ = version
+
+#: The full version of this package including any development levels, as a
+#: tuple of version items, converted to integer where possible.
+#:
+#: Possible formats for this version string are:
+#:
+#: * (M, N, P, 'a1', 'dev7', 'g1234567'): A not yet released version M.N.P
+#: * (M, N, P): A released version M.N.P
+__version_tuple__ = version_tuple
